@@ -128,10 +128,51 @@ enum css_properties_e {
 	CSS_PROP_WRITING_MODE			= 0x06f,
 	CSS_PROP_OVERFLOW_Y			= 0x070,
 	CSS_PROP_BOX_SIZING			= 0x071,
+	CSS_PROP_ALIGN_CONTENT			= 0x072,
+	CSS_PROP_ALIGN_ITEMS			= 0x073,
+	CSS_PROP_ALIGN_SELF			= 0x074,
+	CSS_PROP_FLEX_BASIS			= 0x075,
+	CSS_PROP_FLEX_DIRECTION			= 0x076,
+	CSS_PROP_FLEX_GROW			= 0x077,
+	CSS_PROP_FLEX_SHRINK			= 0x078,
+	CSS_PROP_FLEX_WRAP			= 0x079,
+	CSS_PROP_JUSTIFY_CONTENT		= 0x07a,
+	CSS_PROP_ORDER				= 0x07b,
+	CSS_PROP_FILL_OPACITY			= 0x07c,
+	CSS_PROP_STROKE_OPACITY			= 0x07d,
 
 	CSS_N_PROPERTIES
 };
 
+enum css_align_content_e {
+	CSS_ALIGN_CONTENT_INHERIT		= 0x0,
+	CSS_ALIGN_CONTENT_STRETCH		= 0x1,
+	CSS_ALIGN_CONTENT_FLEX_START		= 0x2,
+	CSS_ALIGN_CONTENT_FLEX_END		= 0x3,
+	CSS_ALIGN_CONTENT_CENTER		= 0x4,
+	CSS_ALIGN_CONTENT_SPACE_BETWEEN		= 0x5,
+	CSS_ALIGN_CONTENT_SPACE_AROUND		= 0x6,
+	CSS_ALIGN_CONTENT_SPACE_EVENLY		= 0x7
+};
+
+enum css_align_items_e {
+	CSS_ALIGN_ITEMS_INHERIT			= 0x0,
+	CSS_ALIGN_ITEMS_STRETCH			= 0x1,
+	CSS_ALIGN_ITEMS_FLEX_START		= 0x2,
+	CSS_ALIGN_ITEMS_FLEX_END		= 0x3,
+	CSS_ALIGN_ITEMS_CENTER			= 0x4,
+	CSS_ALIGN_ITEMS_BASELINE		= 0x5
+};
+
+enum css_align_self_e {
+	CSS_ALIGN_SELF_INHERIT			= CSS_ALIGN_ITEMS_INHERIT,
+	CSS_ALIGN_SELF_STRETCH			= CSS_ALIGN_ITEMS_STRETCH,
+	CSS_ALIGN_SELF_FLEX_START		= CSS_ALIGN_ITEMS_FLEX_START,
+	CSS_ALIGN_SELF_FLEX_END			= CSS_ALIGN_ITEMS_FLEX_END,
+	CSS_ALIGN_SELF_CENTER			= CSS_ALIGN_ITEMS_CENTER,
+	CSS_ALIGN_SELF_BASELINE			= CSS_ALIGN_ITEMS_BASELINE,
+	CSS_ALIGN_SELF_AUTO			= 0x6
+};
 
 enum css_background_attachment_e {
 	CSS_BACKGROUND_ATTACHMENT_INHERIT	= 0x0,
@@ -399,7 +440,11 @@ enum css_display_e {
 	CSS_DISPLAY_TABLE_COLUMN		= 0x0d,
 	CSS_DISPLAY_TABLE_CELL			= 0x0e,
 	CSS_DISPLAY_TABLE_CAPTION		= 0x0f,
-	CSS_DISPLAY_NONE			= 0x10
+	CSS_DISPLAY_NONE			= 0x10,
+	CSS_DISPLAY_FLEX			= 0x11,
+	CSS_DISPLAY_INLINE_FLEX			= 0x12,
+	CSS_DISPLAY_GRID			= 0x13,
+	CSS_DISPLAY_INLINE_GRID			= 0x14
 };
 
 enum css_empty_cells_e {
@@ -408,6 +453,43 @@ enum css_empty_cells_e {
 	CSS_EMPTY_CELLS_HIDE			= 0x2
 };
 
+enum css_fill_opacity_e {
+	CSS_FILL_OPACITY_INHERIT		= 0x0,
+	CSS_FILL_OPACITY_SET			= 0x1
+};
+
+enum css_flex_basis_e {
+	CSS_FLEX_BASIS_INHERIT			= 0x0,
+	CSS_FLEX_BASIS_SET			= 0x1,
+	CSS_FLEX_BASIS_AUTO			= 0x2,
+	CSS_FLEX_BASIS_CONTENT			= 0x3
+};
+
+enum css_flex_direction_e {
+	CSS_FLEX_DIRECTION_INHERIT		= 0x0,
+	CSS_FLEX_DIRECTION_ROW			= 0x1,
+	CSS_FLEX_DIRECTION_ROW_REVERSE		= 0x2,
+	CSS_FLEX_DIRECTION_COLUMN		= 0x3,
+	CSS_FLEX_DIRECTION_COLUMN_REVERSE	= 0x4
+};
+
+enum css_flex_grow_e {
+	CSS_FLEX_GROW_INHERIT			= 0x0,
+	CSS_FLEX_GROW_SET			= 0x1
+};
+
+enum css_flex_shrink_e {
+	CSS_FLEX_SHRINK_INHERIT			= 0x0,
+	CSS_FLEX_SHRINK_SET			= 0x1
+};
+
+enum css_flex_wrap_e {
+	CSS_FLEX_WRAP_INHERIT			= 0x0,
+	CSS_FLEX_WRAP_NOWRAP			= 0x1,
+	CSS_FLEX_WRAP_WRAP			= 0x2,
+	CSS_FLEX_WRAP_WRAP_REVERSE		= 0x3
+};
+
 enum css_float_e {
 	CSS_FLOAT_INHERIT			= 0x0,
 	CSS_FLOAT_LEFT				= 0x1,
@@ -475,6 +557,16 @@ enum css_height_e {
 	CSS_HEIGHT_AUTO				= 0x2
 };
 
+enum css_justify_content_e {
+	CSS_JUSTIFY_CONTENT_INHERIT		= 0x0,
+	CSS_JUSTIFY_CONTENT_FLEX_START		= 0x1,
+	CSS_JUSTIFY_CONTENT_FLEX_END		= 0x2,
+	CSS_JUSTIFY_CONTENT_CENTER		= 0x3,
+	CSS_JUSTIFY_CONTENT_SPACE_BETWEEN	= 0x4,
+	CSS_JUSTIFY_CONTENT_SPACE_AROUND	= 0x5,
+	CSS_JUSTIFY_CONTENT_SPACE_EVENLY	= 0x6
+};
+
 enum css_left_e {
 	CSS_LEFT_INHERIT			= 0x0,
 	CSS_LEFT_SET				= 0x1,
@@ -523,7 +615,44 @@ enum css_list_style_type_e {
 	CSS_LIST_STYLE_TYPE_GEORGIAN		= 0xc,
 	CSS_LIST_STYLE_TYPE_LOWER_ALPHA		= 0xd,
 	CSS_LIST_STYLE_TYPE_UPPER_ALPHA		= 0xe,
-	CSS_LIST_STYLE_TYPE_NONE		= 0xf
+	CSS_LIST_STYLE_TYPE_NONE		= 0xf,
+	CSS_LIST_STYLE_TYPE_BINARY		= 0x10,
+	CSS_LIST_STYLE_TYPE_OCTAL		= 0x11,
+	CSS_LIST_STYLE_TYPE_LOWER_HEXADECIMAL	= 0x12,
+	CSS_LIST_STYLE_TYPE_UPPER_HEXADECIMAL	= 0x13,
+	CSS_LIST_STYLE_TYPE_ARABIC_INDIC	= 0x14,
+	CSS_LIST_STYLE_TYPE_LOWER_ARMENIAN	= 0x15,
+	CSS_LIST_STYLE_TYPE_UPPER_ARMENIAN	= 0x16,
+	CSS_LIST_STYLE_TYPE_BENGALI		= 0x17,
+	CSS_LIST_STYLE_TYPE_CAMBODIAN		= 0x18,
+	CSS_LIST_STYLE_TYPE_KHMER		= 0x19,
+	CSS_LIST_STYLE_TYPE_CJK_DECIMAL		= 0x1a,
+	CSS_LIST_STYLE_TYPE_DEVANAGARI		= 0x1b,
+	CSS_LIST_STYLE_TYPE_GUJARATI		= 0x1c,
+	CSS_LIST_STYLE_TYPE_GURMUKHI		= 0x1d,
+	CSS_LIST_STYLE_TYPE_HEBREW		= 0x1e,
+	CSS_LIST_STYLE_TYPE_KANNADA		= 0x1f,
+	CSS_LIST_STYLE_TYPE_LAO			= 0x20,
+	CSS_LIST_STYLE_TYPE_MALAYALAM		= 0x21,
+	CSS_LIST_STYLE_TYPE_MONGOLIAN		= 0x22,
+	CSS_LIST_STYLE_TYPE_MYANMAR		= 0x23,
+	CSS_LIST_STYLE_TYPE_ORIYA		= 0x24,
+	CSS_LIST_STYLE_TYPE_PERSIAN		= 0x25,
+	CSS_LIST_STYLE_TYPE_TAMIL		= 0x26,
+	CSS_LIST_STYLE_TYPE_TELUGU		= 0x27,
+	CSS_LIST_STYLE_TYPE_THAI		= 0x28,
+	CSS_LIST_STYLE_TYPE_TIBETAN		= 0x29,
+	CSS_LIST_STYLE_TYPE_CJK_EARTHLY_BRANCH	= 0x2a,
+	CSS_LIST_STYLE_TYPE_CJK_HEAVENLY_STEM	= 0x2b,
+	CSS_LIST_STYLE_TYPE_HIAGANA		= 0x2c,
+	CSS_LIST_STYLE_TYPE_HIAGANA_IROHA	= 0x2d,
+	CSS_LIST_STYLE_TYPE_KATAKANA		= 0x2e,
+	CSS_LIST_STYLE_TYPE_KATAKANA_IROHA	= 0x2f,
+	CSS_LIST_STYLE_TYPE_JAPANESE_INFORMAL	= 0x30,
+	CSS_LIST_STYLE_TYPE_JAPANESE_FORMAL	= 0x31,
+	CSS_LIST_STYLE_TYPE_KOREAN_HANGUL_FORMAL	= 0x32,
+	CSS_LIST_STYLE_TYPE_KOREAN_HANJA_INFORMAL	= 0x33,
+	CSS_LIST_STYLE_TYPE_KOREAN_HANJA_FORMAL	= 0x34
 };
 
 enum css_margin_e {
@@ -546,12 +675,14 @@ enum css_max_width_e {
 
 enum css_min_height_e {
 	CSS_MIN_HEIGHT_INHERIT			= 0x0,
-	CSS_MIN_HEIGHT_SET			= 0x1
+	CSS_MIN_HEIGHT_SET			= 0x1,
+	CSS_MIN_HEIGHT_AUTO			= 0x2
 };
 
 enum css_min_width_e {
 	CSS_MIN_WIDTH_INHERIT			= 0x0,
-	CSS_MIN_WIDTH_SET			= 0x1
+	CSS_MIN_WIDTH_SET			= 0x1,
+	CSS_MIN_WIDTH_AUTO			= 0x2
 };
 
 enum css_opacity_e {
@@ -559,6 +690,11 @@ enum css_opacity_e {
 	CSS_OPACITY_SET				= 0x1
 };
 
+enum css_order_e {
+	CSS_ORDER_INHERIT			= 0x0,
+	CSS_ORDER_SET				= 0x1
+};
+
 enum css_outline_color_e {
 	CSS_OUTLINE_COLOR_INHERIT		= CSS_BACKGROUND_COLOR_INHERIT,
 	CSS_OUTLINE_COLOR_COLOR			= CSS_BACKGROUND_COLOR_COLOR,
@@ -634,7 +770,8 @@ enum css_position_e {
 	CSS_POSITION_STATIC			= 0x1,
 	CSS_POSITION_RELATIVE			= 0x2,
 	CSS_POSITION_ABSOLUTE			= 0x3,
-	CSS_POSITION_FIXED			= 0x4
+	CSS_POSITION_FIXED			= 0x4,
+	CSS_POSITION_STICKY			= 0x5
 };
 
 enum css_quotes_e {
@@ -650,6 +787,11 @@ enum css_right_e {
 	CSS_RIGHT_AUTO				= 0x2
 };
 
+enum css_stroke_opacity_e {
+	CSS_STROKE_OPACITY_INHERIT		= 0x0,
+	CSS_STROKE_OPACITY_SET			= 0x1
+};
+
 enum css_table_layout_e {
 	CSS_TABLE_LAYOUT_INHERIT		= 0x0,
 	CSS_TABLE_LAYOUT_AUTO			= 0x1,
